import InputError from '@/Components/InputError';
import InputLabel from '@/Components/InputLabel';
import PrimaryButton from '@/Components/PrimaryButton';
import TextInput from '@/Components/TextInput';
import {Head, Link, useForm} from '@inertiajs/react';
import { FormEventHandler } from 'react';
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout';
import { useState } from 'react';
import { MultiSelect } from '@/Components/MultiSelect';
import { CreateButton } from '@/Components/ui/create-button';

import {
    Select,
    SelectContent,
    SelectGroup,
    SelectItem,
    SelectLabel,
    SelectTrigger,
    SelectValue,
} from "@/Components/ui/select"

import { LineItem, UserCreate } from '@/types';

interface Site {
    site_name: string;
}

export default function CreateUser({roles, user, sites, related_sites, lineItems, related_line_items}: {
    roles: any[];
    user?: any;
    sites: Site[];
    related_sites: string[];
    // lineItems: { data: any[] };
    lineItems: LineItem[];
    related_line_items: string[];
}) {

    const [selectedSites, setSelectedSites] = useState<string[]>(related_sites);

    const [selectedLineItem, setSelectedLineItem] = useState<string[]>(related_line_items);

    const { data, setData, post, processing, errors, reset } = useForm({
        name: user?.name ?? '',
        email: user?.email ?? '',
        password: '',
        password_confirmation: '',
        type: user?.roles[0]?.name ?? '',
        sites: related_sites ?? [] ,
        line_items : related_line_items ?? [],
        _method: user? 'put' : 'post',
    });


    const sitesList = sites.map((item: { site_name: string }) => {
        return {
            value: item.site_name,
            label: item.site_name,
        }
    });


    const lineItemsList = lineItems.map(item=>{
        return {
            value: item.line_item_id,
            label: item.line_item_id,
        }
    });

    const selectChange = (value: string) => {
        setData('type', value);
    }

    const submit: FormEventHandler = (e) => {
        e.preventDefault();

        if(user) {
            post(route('users.update', user?.uuid));
        }else {
            post(route('users.store'), {
                onFinish: () => reset('password', 'password_confirmation'),
            });
        }

    };

    return (
        <AuthenticatedLayout>
            <Head title={ user ? 'Edit' : 'Create'} />
             <div className="bg-white shadow-md rounded px-8 pt-6 m-5 pb-8 mb-4 ">
                <div className={'flex justify-between  p-3'}>

                    <div className={"pb-5 text-2xl font-bold"}>
                        <strong>{ user ? 'Edit' : 'Create'} User</strong>
                    </div>
                    <div>
                        <div className={'flex mx-4 gap-2'}>
                                <Link href={'/users'}
                                className={
                                        "inline-flex items-center rounded-md border border-transparent bg-gray-800 px-4 py-2 text-xs font-semibold uppercase tracking-widest text-white transitionduration-150 ease-in-out hover:bg-gray-700 focus:bg-gray-700 focus:outline-none focus:ring-2 focus:ring-indigo-500 focus:ring-offset-2 active:bg-gray-900"
                                    }
                                >Back</Link>
                        </div>

                    </div>
                </div>
                <form onSubmit={submit} className='w-full max-w-3xl'>
                <div className="grid gap-4 sm:grid-cols-2 sm:gap-6">
                    <div className='w-full mt-4'>
                        <InputLabel htmlFor="name" value="Name"/>
                        <TextInput
                            id="name"
                            name="name"
                            value={data.name}
                            className="mt-1 block w-full"
                            autoComplete="name"
                            isFocused={true}
                            onChange={(e) => setData('name', e.target.value)}
                            required
                        />
                        <InputError message={errors.name} className="mt-2"/>
                    </div>

                    <div className="mt-4 w-full">
                        <InputLabel htmlFor="email" value="Email"/>
                        <TextInput
                            id="email"
                            type="email"
                            name="email"
                            value={data.email}
                            className="mt-1 block w-full"
                            autoComplete="username"
                            onChange={(e) => setData('email', e.target.value)}
                            required
                        />
                        <InputError message={errors.email} className="mt-2"/>
                    </div>

                    { user ? '' :
                        <>
                        <div className="mt-4 w-full">
                        <InputLabel htmlFor="password" value="Password"/>

                        <TextInput
                            id="password"
                            type="password"
                            name="password"
                            value={data.password}
                            className="mt-1 block w-full"
                            autoComplete="new-password"
                            onChange={(e) => setData('password', e.target.value)}
                            required
                        />

                        <InputError message={errors.password} className="mt-2"/>
                    </div>

                    <div className="mt-4 w-full">
                        <InputLabel
                            htmlFor="password_confirmation"
                            value="Confirm Password"
                        />

                        <TextInput
                            id="password_confirmation"
                            type="password"
                            name="password_confirmation"
                            value={data.password_confirmation}
                            className="mt-1 block w-full"
                            autoComplete="new-password"
                            onChange={(e) =>
                                setData('password_confirmation', e.target.value)
                            }
                            required
                        />

                        <InputError
                            message={errors.password_confirmation}
                            className="mt-2"
                        />
                    </div>
                        </>
                        }
                        <div className="mt-4 w-full">
                        <InputLabel htmlFor="type" value="Type"/>

                        <Select name="type" onValueChange={selectChange}
                                value={data.type}
                        >
                            <SelectTrigger className="w-full mt-1 ">
                                <SelectValue placeholder="Select a user type" />
                            </SelectTrigger>
                            <SelectContent>
                                <SelectGroup>
                                    <SelectLabel>Types</SelectLabel>
                                    {roles.map((item) =>
                                        <SelectItem value={item.type} key={item.type}>{item.type}</SelectItem>
                                    )}

                                </SelectGroup>
                            </SelectContent>
                        </Select>
                        <InputError message={errors.type} className="mt-2"/>
                    </div>
                    <div className='mt-4 w-full'>
                        {data.type === 'Publisher' ? (
                                <>
                                    <InputLabel htmlFor="type" value="Sites" />
                                    <MultiSelect
                                        options={sitesList}
                                        onValueChange={(selectedValues:string[]) => {
                                            setSelectedSites(selectedValues); // Update state
                                            setData('sites', selectedValues); // Update form data
                                        }}
                                        defaultValue={selectedSites}
                                        placeholder="Select sites"
                                        variant="inverted"
                                        animation={2}
                                        maxCount={3}
                                        name="sites"
                                    />
                                </>
                            ) : (
                                <>
                                    <InputLabel htmlFor="type" value="Line items" />
                                    <MultiSelect
                                        options={lineItemsList}
                                        onValueChange={(selectedValues) => {
                                            setSelectedLineItem(selectedValues); // Update state
                                            setData('line_items', selectedValues); // Update form data
                                        }}
                                        defaultValue={selectedLineItem}
                                        placeholder="Select line items"
                                        variant="inverted"
                                        animation={2}
                                        maxCount={3}
                                        name="line_items"
                                    />
                                </>
                        )}
                    </div>
                    <div className='mt-4 w-full'>

                    </div>
                </div>
                    <div className="mt-4 flex items-center justify-end">
                        <CreateButton className="ms-4" disabled={processing}>
                            {user ? 'Update' : 'Create'}
                        </CreateButton>
                    </div>
                </form>
             </div>
        </AuthenticatedLayout>
    );
}
